@@ -11,7 +11,6 @@ import json
 import os
 from past.builtins import basestring
 
-from .config import get_user_config
 from .utils import make_sure_path_exists
 
 
@@ -20,7 +19,10 @@ def get_file_name(replay_dir, template_name):
     return os.path.join(replay_dir, file_name)
 
 
-def dump(template_name, context):
+def dump(replay_dir, template_name, context):
+    if not make_sure_path_exists(replay_dir):
+        raise IOError('Unable to create replay dir at {}'.format(replay_dir))
+
     if not isinstance(template_name, basestring):
         raise TypeError('Template name is required to be of type str')
 
@@ -30,22 +32,16 @@ def dump(template_name, context):
     if 'cookiecutter' not in context:
         raise ValueError('Context is required to contain a cookiecutter key')
 
-    replay_dir = get_user_config()['replay_dir']
-
-    if not make_sure_path_exists(replay_dir):
-        raise IOError('Unable to create replay dir at {}'.format(replay_dir))
-
     replay_file = get_file_name(replay_dir, template_name)
 
     with open(replay_file, 'w') as outfile:
         json.dump(context, outfile)
 
 
-def load(template_name):
+def load(replay_dir, template_name):
     if not isinstance(template_name, basestring):
         raise TypeError('Template name is required to be of type str')
 
-    replay_dir = get_user_config()['replay_dir']
     replay_file = get_file_name(replay_dir, template_name)
 
     with open(replay_file, 'r') as infile:
